@@ -170,10 +170,10 @@ class SECE_model(object):
             self.makeLog(f"Model1 batch_size: {batch_size}")
 
 
-    def predict_model1(self):
+    def predict_model1(self, batch_size=512):
         
         self.model1.eval()
-        dataloader = DataLoader(self.dataset1, shuffle=False, batch_size=len(self.dataset1), num_workers=self.num_workers)
+        dataloader = DataLoader(self.dataset1, shuffle=False, batch_size=batch_size, num_workers=self.num_workers)
         
         mean = torch.empty(size=[0,self.n_input])
         z = torch.empty(size=[0,self.n_latent])
